Learn R Programming

prevederer (version 0.0.1)

prevedere_raw_model: Raw model

Description

Returns all information about a forecast model.

Usage

prevedere_raw_model(key, model_id, exclude_indicators = TRUE,
  as_of_date = NULL, raw = FALSE)

Arguments

key

A Prevedere API key.

model_id

UUID for the forecast model.

exclude_indicators

Whether to return only indicators used in model (TRUE), or all associated indicators.

as_of_date

Get the model only using data up to the specified date (YYYY-MM-DD). Used for backtesting.

raw

Logical value indicating if data should be returned in its raw form (typically nested lists) or formatted as appropriate, usually a dataframe.

Value

A list of model components and metadata, including indicators, coefficients, and the model start date.

See Also

Other forecast model functions: prevedere_forecast

Examples

Run this code
# NOT RUN {
k <- "1235467abcdefg"

prevedere_raw_model(key = k, model_id = "1b1878399833c7f38b094e54dd43d374")

## Backtest
prevedere_raw_model(key = k,
                    model_id = "1b1878399833c7f38b094e54dd43d374",
                    as_of_data = "2019-05-01")
# }

Run the code above in your browser using DataLab